﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 리스트 컬렉션 뷰
        /// </summary>
        private ListCollectionView listCollectionView;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        [STAThread]
        public static void Main()
        {
            Application application = new Application();

            application.Run(new MainWindow());
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Open 실행하기 - ExecuteOpen(sender, e)

        /// <summary>
        /// Open 실행하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void ExecuteOpen(object sender, ExecutedRoutedEventArgs e)
        {
            People people = People.Load(this);

            if(people != null)
            {
                this.listCollectionView = new ListCollectionView(people);

                this.listCollectionView.SortDescriptions.Add(new SortDescription("LastName", ListSortDirection.Ascending));

                this.listBox.ItemsSource = this.listCollectionView;

                if(this.listBox.Items.Count > 0)
                {
                    this.listBox.SelectedIndex = 0;
                }

                this.allRadioButton.IsChecked = true;
            }
        }

        #endregion
        #region 생존자 필터 처리하기 - LivingPersionFilter(value)

        /// <summary>
        /// 생존자 필터 처리하기
        /// </summary>
        /// <param name="value">값</param>
        /// <returns>처리 결과</returns>
        private bool LivingPersionFilter(object value)
        {
            return (value as Person).DeathDate == null;
        }

        #endregion
        #region 사망자 필터 처리하기 - DeadPersonFilter(value)

        /// <summary>
        /// 사망자 필터 처리하기
        /// </summary>
        /// <param name="value">값</param>
        /// <returns>처리 결과</returns>
        private bool DeadPersonFilter(object value)
        {
            return (value as Person).DeathDate != null;
        }

        #endregion
        #region 라디오 버튼 체크 변경시 처리하기 - radioButton_Checked(sender, e)

        /// <summary>
        /// 라디오 버튼 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void radioButton_Checked(object sender, RoutedEventArgs e)
        {
            if(this.listCollectionView == null)
            {
                return;
            }

            RadioButton radioButton = e.Source as RadioButton;

            switch(radioButton.Name)
            {
                case "livingRadioButton" : this.listCollectionView.Filter = LivingPersionFilter; break;
                case "deadRadioButton"   : this.listCollectionView.Filter = DeadPersonFilter;    break;
                case "allRadioButton"    : this.listCollectionView.Filter = null;                break;
            }
        }

        #endregion
    }
}