﻿using Microsoft.Win32;
using System;
using System.IO;
using System.Collections.ObjectModel;
using System.Windows;
using System.Xml.Serialization;

namespace TestProject
{
    /// <summary>
    /// 사람들
    /// </summary>
    public class People : ObservableCollection<Person>
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 필터
        /// </summary>
        private const string FILTER = "People XML files (*.PeopleXml)|*.PeopleXml|All files (*.*)|*.*";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 로드하기 - Load(window)

        /// <summary>
        /// 로드하기
        /// </summary>
        /// <param name="window">윈도우</param>
        /// <returns>사람들</returns>
        public static People Load(Window window)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();

            openFileDialog.Filter = FILTER;

            People people = null;

            if((bool)openFileDialog.ShowDialog(window))
            {
                try
                {
                    StreamReader streamReader = new StreamReader(openFileDialog.FileName);

                    XmlSerializer xmlSerializer = new XmlSerializer(typeof(People));

                    people = (People)xmlSerializer.Deserialize(streamReader);

                    streamReader.Close();
                }
                catch(Exception exception)
                {
                    MessageBox.Show
                    (
                        "Could not load file: " + exception.Message,
                        window.Title,
                        MessageBoxButton.OK,
                        MessageBoxImage.Exclamation
                    );

                    people = null;
                }
            }

            return people;
        }

        #endregion
        #region 저장하기 - Save(window)

        /// <summary>
        /// 저장하기
        /// </summary>
        /// <param name="window">윈도우</param>
        /// <returns>처리 결과</returns>
        public bool Save(Window window)
        {
            SaveFileDialog saveFileDialog = new SaveFileDialog();

            saveFileDialog.Filter = FILTER;

            if((bool)saveFileDialog.ShowDialog(window))
            {
                try
                {
                    StreamWriter streamWriter = new StreamWriter(saveFileDialog.FileName);

                    XmlSerializer xmlSerializer = new XmlSerializer(GetType());

                    xmlSerializer.Serialize(streamWriter, this);

                    streamWriter.Close();
                }
                catch(Exception exception)
                {
                    MessageBox.Show
                    (
                        "Could not save file: " + exception.Message,
                        window.Title,
                        MessageBoxButton.OK,
                        MessageBoxImage.Exclamation
                    );

                    return false;
                }
            }

            return true;
        }

        #endregion
    }
}