﻿using System;
using System.ComponentModel;
using System.Xml.Serialization;

namespace TestProject
{
    /// <summary>
    /// 사람
    /// </summary>
    public class Person: INotifyPropertyChanged
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Event
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 속성 변경시 - PropertyChanged

        /// <summary>
        /// 속성 변경시
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 이름
        /// </summary>
        private string firstName = "<first name>";

        /// <summary>
        /// 중간 이름
        /// </summary>
        private string middleName = string.Empty;

        /// <summary>
        /// 성
        /// </summary>
        private string lastName = "<last name>";

        /// <summary>
        /// 생일
        /// </summary>
        private DateTime? birthDate = new DateTime(1800, 1, 1);

        /// <summary>
        /// 사망일
        /// </summary>
        private DateTime? deathDate = new DateTime(1900, 12, 31);

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 이름 - FirstName

        /// <summary>
        /// 이름
        /// </summary>
        public string FirstName
        {
            set
            {
                this.firstName = value;

                OnPropertyChanged("FirstName");
            }
            get
            {
                return this.firstName;
            }
        }

        #endregion
        #region 중간 이름 - MiddleName

        /// <summary>
        /// 중간 이름
        /// </summary>
        public string MiddleName
        {
            set
            {
                this.middleName = value;

                OnPropertyChanged("MiddleName");
            }
            get
            {
                return this.middleName;
            }
        }

        #endregion
        #region 성 - LastName

        /// <summary>
        /// 성
        /// </summary>
        public string LastName
        {
            set
            {
                this.lastName = value;

                OnPropertyChanged("LastName");
            }
            get
            {
                return this.lastName;
            }
        }

        #endregion
        #region 생일 - BirthDate

        /// <summary>
        /// 생일
        /// </summary>
        [XmlElement(DataType = "date")]
        public DateTime? BirthDate
        {
            set
            {
                this.birthDate = value;

                OnPropertyChanged("BirthDate");
            }
            get
            {
                return this.birthDate;
            }
        }

        #endregion
        #region 사망일 - DeathDate

        /// <summary>
        /// 사망일
        /// </summary>
        [XmlElement(DataType = "date")]
        public DateTime? DeathDate
        {
            set
            {
                this.deathDate = value;

                OnPropertyChanged("DeathDate");
            }
            get
            {
                return this.deathDate;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 속성 변경시 처리하기 - OnPropertyChanged(propertyName)

        /// <summary>
        /// 속성 변경시 처리하기
        /// </summary>
        /// <param name="propertyName">속성명</param>
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if(PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}